#!/bin/bash

cd /usr/share/Sensor_Mezzanine_Getting_Started/tweeting_doorbell

ssid=$(iw wlan0 info| grep "ssid" | cut -d " " -f 2)
if [[ -z "${ssid// }" ]]; then
	make run TWEET=notweet
else
	date -s "$(curl -s --head http://google.com | grep ^Date: | sed 's/Date: //g')"
	make run TWEET=$1
fi
